@@ -128,8 +128,9 @@ col_skip <- function() {
 
 #' Parse numbers, flexibly
 #'
-#' This drops any non-numeric characters before or after the first number.
-#' The grouping mark specified by the locale is ignored inside the number.
+#' This parses the first number it finds, dropping any non-numeric characters
+#' before the first number and all characters after the first number. The
+#' grouping mark specified by the locale is ignored inside the number.
 #'
 #' @inheritParams parse_atomic
 #' @inheritParams tokenizer_delim
@@ -139,8 +140,9 @@ col_skip <- function() {
 #' @export
 #' @examples
 #' ## These all return 1000
-#' parse_number("$1,000")     ## leading $ and grouping character , ignored
-#' parse_number("euro1,000")  ## leading non-numeric euro ignored
+#' parse_number("$1,000") ## leading `$` and grouping character `,` ignored
+#' parse_number("euro1,000") ## leading non-numeric euro ignored
+#' parse_number("t1000t1000") ## only parses first number found
 #'
 #' parse_number("1,234.56")
 #' ## explicit locale specifying European grouping and decimal marks
@@ -180,8 +182,8 @@ col_number <- function() {
 #' parse_guess(c("FALSE", "TRUE", "F", "T"))
 #'
 #' # Integers and doubles
-#' parse_guess(c("1","2","3"))
-#' parse_guess(c("1.6","2.6","3.4"))
+#' parse_guess(c("1", "2", "3"))
+#' parse_guess(c("1.6", "2.6", "3.4"))
 #'
 #' # Numbers containing grouping mark
 #' guess_parser("1,234,566")
@@ -214,33 +216,42 @@ guess_parser <- function(x, locale = default_locale(), guess_integer = FALSE, na
 
 #' Parse factors
 #'
-#' `parse_factor` is similar to [factor()], but will generate
-#' warnings if elements of `x` are not found in `levels`.
+#' `parse_factor()` is similar to [factor()], but generates a warning if
+#' `levels` have been specified and some elements of `x` are not found in those
+#' `levels`.
 #'
-#' @param levels Character vector providing set of allowed levels. if `NULL`,
-#'   will generate levels based on the unique values of `x`, ordered by order
-#'   of appearance in `x`.
+#' @param levels Character vector of the allowed levels. When `levels = NULL`
+#'   (the default), `levels` are discovered from the unique values of `x`, in
+#'   the order in which they appear in `x`.
 #' @param ordered Is it an ordered factor?
-#' @param include_na If `NA` are present, include as an explicit factor to level?
+#' @param include_na If `TRUE` and `x` contains at least one `NA`, then `NA`
+#'   is included in the levels of the constructed factor.
+#'
 #' @inheritParams parse_atomic
 #' @inheritParams tokenizer_delim
 #' @inheritParams read_delim
 #' @family parsers
 #' @export
 #' @examples
-#' parse_factor(c("a", "b"), letters)
+#' # discover the levels from the data
+#' parse_factor(c("a", "b"))
+#' parse_factor(c("a", "b", "-99"))
+#' parse_factor(c("a", "b", "-99"), na = c("", "NA", "-99"))
+#' parse_factor(c("a", "b", "-99"), na = c("", "NA", "-99"), include_na = FALSE)
+#'
+#' # provide the levels explicitly
+#' parse_factor(c("a", "b"), levels = letters[1:5])
 #'
 #' x <- c("cat", "dog", "caw")
-#' levels <- c("cat", "dog", "cow")
+#' animals <- c("cat", "dog", "cow")
 #'
-#' # Base R factor() silently converts unknown levels to NA
-#' x1 <- factor(x, levels)
+#' # base::factor() silently converts elements that do not match any levels to
+#' # NA
+#' factor(x, levels = animals)
 #'
-#' # parse_factor generates a warning & problems
-#' x2 <- parse_factor(x, levels)
-#'
-#' # Using an argument of `NULL` will generate levels based on values of `x`
-#' x2 <- parse_factor(x, levels = NULL)
+#' # parse_factor() generates same factor as base::factor() but throws a warning
+#' # and reports problems
+#' parse_factor(x, levels = animals)
 parse_factor <- function(x, levels = NULL, ordered = FALSE, na = c("", "NA"),
                          locale = default_locale(), include_na = TRUE, trim_ws = TRUE) {
   parse_vector(x, col_factor(levels, ordered, include_na), na = na, locale = locale, trim_ws = trim_ws)
@@ -249,6 +260,9 @@ parse_factor <- function(x, levels = NULL, ordered = FALSE, na = c("", "NA"),
 #' @rdname parse_factor
 #' @export
 col_factor <- function(levels = NULL, ordered = FALSE, include_na = FALSE) {
+  if (!(is.null(levels) || is.character(levels))) {
+    stop(sprintf("`levels` must be `NULL` or a character vector:\n- `levels` is a '%s'", class(levels)), call. = FALSE)
+  }
   collector("factor", levels = levels, ordered = ordered, include_na = include_na)
 }
 
@@ -260,55 +274,48 @@ col_factor <- function(levels = NULL, ordered = FALSE, include_na = FALSE) {
 #' `readr` uses a format specification similar to [strptime()].
 #' There are three types of element:
 #'
-#' \enumerate{
-#'   \item Date components are specified with "\%" followed by a letter.
-#'     For example "\%Y" matches a 4 digit year, "\%m", matches a 2 digit
-#'     month and "\%d" matches a 2 digit day. Month and day default to `1`,
-#'     (i.e. Jan 1st) if not present, for example if only a year is given.
-#'   \item Whitespace is any sequence of zero or more whitespace characters.
-#'   \item Any other character is matched exactly.
-#' }
+#' 1. Date components are specified with "%" followed by a letter. For example
+#'   "%Y" matches a 4 digit year, "%m", matches a 2 digit month and "%d" matches
+#'   a 2 digit day. Month and day default to `1`, (i.e. Jan 1st) if not present,
+#'   for example if only a year is given.
+#' 2. Whitespace is any sequence of zero or more whitespace characters.
+#' 3. Any other character is matched exactly.
 #'
 #' `parse_datetime()` recognises the following format specifications:
-#' \itemize{
-#'   \item Year: "\%Y" (4 digits). "\%y" (2 digits); 00-69 -> 2000-2069,
-#'     70-99 -> 1970-1999.
-#'   \item Month: "\%m" (2 digits), "\%b" (abbreviated name in current
-#'     locale), "\%B" (full name in current locale).
-#'   \item Day: "\%d" (2 digits), "\%e" (optional leading space),
-#'     "%a" (abbreviated name in current locale).
-#'   \item Hour: "\%H" or "\%I" or "\%h", use I (and not H) with AM/PM,
-#'     use h (and not H) if your times represent durations longer than one day.
-#'   \item Minutes: "\%M"
-#'   \item Seconds: "\%S" (integer seconds), "\%OS" (partial seconds)
-#'   \item Time zone: "\%Z" (as name, e.g. "America/Chicago"), "\%z" (as
-#'     offset from UTC, e.g. "+0800")
-#'   \item AM/PM indicator: "\%p".
-#'   \item Non-digits: "\%." skips one non-digit character,
-#'     "\%+" skips one or more non-digit characters,
-#'     "\%*" skips any number of non-digits characters.
-#'   \item Automatic parsers: "\%AD" parses with a flexible YMD parser,
-#'      "\%AT" parses with a flexible HMS parser.
-#'   \item Shortcuts: "\%D" = "\%m/\%d/\%y",  "\%F" = "\%Y-\%m-\%d",
-#'       "\%R" = "\%H:\%M", "\%T" = "\%H:\%M:\%S",  "\%x" = "\%y/\%m/\%d".
-#' }
+#'
+#' * Year: "%Y" (4 digits). "%y" (2 digits); 00-69 -> 2000-2069, 70-99 ->
+#'   1970-1999.
+#' * Month: "%m" (2 digits), "%b" (abbreviated name in current locale), "%B"
+#'   (full name in current locale).
+#' * Day: "%d" (2 digits), "%e" (optional leading space), "%a" (abbreviated
+#'   name in current locale).
+#' * Hour: "%H" or "%I" or "%h", use I (and not H) with AM/PM, use h (and not H)
+#'   if your times represent durations longer than one day.
+#' * Minutes: "%M"
+#' * Seconds: "%S" (integer seconds), "%OS" (partial seconds)
+#' * Time zone: "%Z" (as name, e.g. "America/Chicago"), "%z" (as offset from
+#'   UTC, e.g. "+0800")
+#' * AM/PM indicator: "%p".
+#' * Non-digits: "%." skips one non-digit character, "%+" skips one or more
+#'   non-digit characters, "%*" skips any number of non-digits characters.
+#' * Automatic parsers: "%AD" parses with a flexible YMD parser, "%AT" parses
+#'   with a flexible HMS parser.
+#' * Time since the Unix epoch: "%s" decimal seconds since the Unix epoch.
+#' * Shortcuts: "%D" = "%m/%d/%y", "%F" = "%Y-%m-%d", "%R" = "%H:%M", "%T" =
+#'   "%H:%M:%S", "%x" = "%y/%m/%d".
 #'
 #' @section ISO8601 support:
 #'
 #' Currently, readr does not support all of ISO8601. Missing features:
 #'
-#' \itemize{
-#' \item Week & weekday specifications, e.g. "2013-W05", "2013-W05-10"
-#' \item Ordinal dates, e.g. "2013-095".
-#' \item Using commas instead of a period for decimal separator
-#' }
+#' * Week & weekday specifications, e.g. "2013-W05", "2013-W05-10".
+#' * Ordinal dates, e.g. "2013-095".
+#' * Using commas instead of a period for decimal separator.
 #'
 #' The parser is also a little laxer than ISO8601:
 #'
-#' \itemize{
-#' \item Dates and times can be separated with a space, not just T.
-#' \item Mostly correct specifications like "2009-05-19 14:" and  "200912-01" work.
-#' }
+#' * Dates and times can be separated with a space, not just T.
+#' * Mostly correct specifications like "2009-05-19 14:" and "200912-01" work.
 #'
 #' @param x A character vector of dates to parse.
 #' @param format A format specification, as described below. If set to "",
@@ -346,9 +353,11 @@ col_factor <- function(levels = NULL, ordered = FALSE, include_na = FALSE) {
 #' # Use the locale parameter to control the default time zone
 #' # (but note UTC is considerably faster than other options)
 #' parse_datetime("2010/01/01 12:00", "%Y/%m/%d %H:%M",
-#'   locale = locale(tz = "US/Central"))
+#'   locale = locale(tz = "US/Central")
+#' )
 #' parse_datetime("2010/01/01 12:00", "%Y/%m/%d %H:%M",
-#'   locale = locale(tz = "US/Eastern"))
+#'   locale = locale(tz = "US/Eastern")
+#' )
 #'
 #' # Unlike strptime, the format specification must match the complete
 #' # string (ignoring leading and trailing whitespace). This avoids common
