@@ -62,15 +62,21 @@ melt_delim <- function(file, delim, quote = '"',
 
   if (!nzchar(delim)) {
     stop("`delim` must be at least one character, ",
-      "use `melt_table()` for whitespace delimited input.", call. = FALSE)
+      "use `melt_table()` for whitespace delimited input.",
+      call. = FALSE
+    )
   }
-  tokenizer <- tokenizer_delim(delim, quote = quote,
+  tokenizer <- tokenizer_delim(delim,
+    quote = quote,
     escape_backslash = escape_backslash, escape_double = escape_double,
     na = na, quoted_na = quoted_na, comment = comment, trim_ws = trim_ws,
-    skip_empty_rows = skip_empty_rows)
-  melt_delimited(file, tokenizer, locale = locale, skip = skip,
+    skip_empty_rows = skip_empty_rows
+  )
+  melt_delimited(file, tokenizer,
+    locale = locale, skip = skip,
     skip_empty_rows = skip_empty_rows, comment = comment,
-    n_max = n_max, progress = progress)
+    n_max = n_max, progress = progress
+  )
 }
 
 #' @rdname melt_delim
@@ -84,11 +90,15 @@ melt_csv <- function(file, locale = default_locale(), na = c("", "NA"),
     lifecycle::deprecate_soft("2.0.0", what = "melt_csv()", details = "Please use `meltr::melt_csv()` instead")
   }
 
-  tokenizer <- tokenizer_csv(na = na, quoted_na = quoted_na, quote = quote,
-    comment = comment, trim_ws = trim_ws, skip_empty_rows = skip_empty_rows)
-  melt_delimited(file, tokenizer, locale = locale, skip = skip,
+  tokenizer <- tokenizer_csv(
+    na = na, quoted_na = quoted_na, quote = quote,
+    comment = comment, trim_ws = trim_ws, skip_empty_rows = skip_empty_rows
+  )
+  melt_delimited(file, tokenizer,
+    locale = locale, skip = skip,
     skip_empty_rows = skip_empty_rows, comment = comment, n_max = n_max,
-    progress = progress)
+    progress = progress
+  )
 }
 
 #' @rdname melt_delim
@@ -107,12 +117,16 @@ melt_csv2 <- function(file, locale = default_locale(), na = c("", "NA"),
     locale$decimal_mark <- ","
     locale$grouping_mark <- "."
   }
-  tokenizer <- tokenizer_delim(delim = ";", na = na, quoted_na = quoted_na,
+  tokenizer <- tokenizer_delim(
+    delim = ";", na = na, quoted_na = quoted_na,
     quote = quote, comment = comment, trim_ws = trim_ws,
-    skip_empty_rows = skip_empty_rows)
-  melt_delimited(file, tokenizer, locale = locale, skip = skip,
+    skip_empty_rows = skip_empty_rows
+  )
+  melt_delimited(file, tokenizer,
+    locale = locale, skip = skip,
     skip_empty_rows = skip_empty_rows, comment = comment, n_max = n_max,
-    progress = progress)
+    progress = progress
+  )
 }
 
 
@@ -127,28 +141,47 @@ melt_tsv <- function(file, locale = default_locale(), na = c("", "NA"),
     lifecycle::deprecate_soft("2.0.0", what = "melt_tsv()", details = "Please use `meltr::melt_tsv()` instead")
   }
 
-  tokenizer <- tokenizer_tsv(na = na, quoted_na = quoted_na, quote = quote,
-    comment = comment, trim_ws = trim_ws, skip_empty_rows = skip_empty_rows)
-  melt_delimited(file, tokenizer, locale = locale, skip = skip,
+  tokenizer <- tokenizer_tsv(
+    na = na, quoted_na = quoted_na, quote = quote,
+    comment = comment, trim_ws = trim_ws, skip_empty_rows = skip_empty_rows
+  )
+  melt_delimited(file, tokenizer,
+    locale = locale, skip = skip,
     skip_empty_rows = skip_empty_rows, comment = comment, n_max = n_max,
-    progress = progress)
+    progress = progress
+  )
 }
 
 # Helper functions for reading from delimited files ----------------------------
 col_spec_melt <-
-  structure(list(row = structure(list(),
-                                 class = c("collector_double",
-                                           "collector")),
-                 col = structure(list(),
-                                 class = c("collector_double",
-                                           "collector")),
-                 data_type = structure(list(),
-                                       class = c("collector_character",
-                                                 "collector")),
-                 value = structure(list(),
-                                   class = c("collector_character",
-                                             "collector"))),
-            .Names = c("row", "col", "data_type", "value"))
+  structure(list(
+    row = structure(list(),
+      class = c(
+        "collector_double",
+        "collector"
+      )
+    ),
+    col = structure(list(),
+      class = c(
+        "collector_double",
+        "collector"
+      )
+    ),
+    data_type = structure(list(),
+      class = c(
+        "collector_character",
+        "collector"
+      )
+    ),
+    value = structure(list(),
+      class = c(
+        "collector_character",
+        "collector"
+      )
+    )
+  ),
+  .Names = c("row", "col", "data_type", "value")
+  )
 
 melt_tokens <- function(data, tokenizer, locale_, n_max, progress) {
   if (n_max == Inf) {
@@ -167,8 +200,10 @@ melt_delimited <- function(file, tokenizer, locale = default_locale(),
     data <- datasource_connection(file, skip, skip_empty_rows = skip_empty_rows, comment)
   } else {
     if (empty_file(file)) {
-       return(tibble::tibble(row = double(), col = double(),
-                             data_type = character(), value = character()))
+      return(tibble::tibble(
+        row = double(), col = double(),
+        data_type = character(), value = character()
+      ))
     }
     if (is.character(file) && identical(locale$encoding, "UTF-8")) {
       # When locale is not set, file is probablly marked as its correct encoding.
@@ -179,7 +214,9 @@ melt_delimited <- function(file, tokenizer, locale = default_locale(),
     }
   }
   ds <- datasource(data, skip = skip, skip_empty_rows = skip_empty_rows, comment = comment)
-  out <- melt_tokens(ds, tokenizer, locale_ = locale, n_max = n_max,
-              progress = progress)
+  out <- melt_tokens(ds, tokenizer,
+    locale_ = locale, n_max = n_max,
+    progress = progress
+  )
   warn_problems(out)
 }
