@@ -1,14 +1,17 @@
 # nocov start
 .onLoad <- function(libname, pkgname) {
+  tzdb::tzdb_initialize()
+
   register_s3_method("testthat", "compare", "col_spec")
   register_s3_method("testthat", "compare", "tbl_df")
+  register_s3_method("waldo", "compare_proxy", "spec_tbl_df")
 
   opt <- options()
   opt_readr <- list(
     readr.show_progress = TRUE
   )
   to_set <- !(names(opt_readr) %in% names(opt))
-  if(any(to_set)) options(opt_readr[to_set])
+  if (any(to_set)) options(opt_readr[to_set])
   invisible()
 }
 
@@ -19,9 +22,9 @@ release_questions <- function() {
 }
 
 register_s3_method <- function(pkg, generic, class, fun = NULL) {
-  stopifnot(is.character(pkg), length(pkg) == 1)
-  stopifnot(is.character(generic), length(generic) == 1)
-  stopifnot(is.character(class), length(class) == 1)
+  check_string(pkg)
+  check_string(generic)
+  check_string(class)
 
   if (is.null(fun)) {
     fun <- get(paste0(generic, ".", class), envir = parent.frame())
