@@ -1,60 +1,64 @@
-#include <Rcpp.h>
-using namespace Rcpp;
+#include "cpp11/list.hpp"
 
 #include "Collector.h"
 #include "LocaleInfo.h"
 #include "QiParsers.h"
 #include "utils.h"
 
-CollectorPtr Collector::create(List spec, LocaleInfo* pLocale) {
-  std::string subclass(as<CharacterVector>(spec.attr("class"))[0]);
+CollectorPtr Collector::create(const cpp11::list& spec, LocaleInfo* pLocale) {
+  std::string subclass(cpp11::as_cpp<cpp11::strings>(spec.attr("class"))[0]);
 
-  if (subclass == "collector_skip")
+  if (subclass == "collector_skip") {
     return CollectorPtr(new CollectorSkip());
-  if (subclass == "collector_logical")
+  }
+  if (subclass == "collector_logical") {
     return CollectorPtr(new CollectorLogical());
-  if (subclass == "collector_integer")
+  }
+  if (subclass == "collector_integer") {
     return CollectorPtr(new CollectorInteger());
+  }
   if (subclass == "collector_double") {
     return CollectorPtr(new CollectorDouble(pLocale->decimalMark_));
   }
-  if (subclass == "collector_number")
+  if (subclass == "collector_number") {
     return CollectorPtr(
         new CollectorNumeric(pLocale->decimalMark_, pLocale->groupingMark_));
-  if (subclass == "collector_character")
+  }
+  if (subclass == "collector_character") {
     return CollectorPtr(new CollectorCharacter(&pLocale->encoder_));
+  }
   if (subclass == "collector_date") {
     SEXP format_ = spec["format"];
-    std::string format =
-        (Rf_isNull(format_)) ? pLocale->dateFormat_ : as<std::string>(format_);
+    std::string format = (Rf_isNull(format_)) != 0U
+                             ? pLocale->dateFormat_
+                             : cpp11::as_cpp<std::string>(format_);
     return CollectorPtr(new CollectorDate(pLocale, format));
   }
   if (subclass == "collector_datetime") {
-    std::string format = as<std::string>(spec["format"]);
+    std::string format = cpp11::as_cpp<std::string>(spec["format"]);
     return CollectorPtr(new CollectorDateTime(pLocale, format));
   }
   if (subclass == "collector_time") {
-    std::string format = as<std::string>(spec["format"]);
+    std::string format = cpp11::as_cpp<std::string>(spec["format"]);
     return CollectorPtr(new CollectorTime(pLocale, format));
   }
   if (subclass == "collector_factor") {
-    Nullable<CharacterVector> levels =
-        as<Nullable<CharacterVector> >(spec["levels"]);
-    bool ordered = as<bool>(spec["ordered"]);
-    bool includeNa = as<bool>(spec["include_na"]);
+    cpp11::sexp levels(spec["levels"]);
+    bool ordered = cpp11::as_cpp<bool>(spec["ordered"]);
+    bool includeNa = cpp11::as_cpp<bool>(spec["include_na"]);
     return CollectorPtr(
         new CollectorFactor(&pLocale->encoder_, levels, ordered, includeNa));
   }
 
-  Rcpp::stop("Unsupported column type");
+  cpp11::stop("Unsupported column type");
   return CollectorPtr(new CollectorSkip());
 }
 
 std::vector<CollectorPtr>
-collectorsCreate(ListOf<List> specs, LocaleInfo* pLocale) {
+collectorsCreate(const cpp11::list& specs, LocaleInfo* pLocale) {
   std::vector<CollectorPtr> collectors;
-  for (int j = 0; j < specs.size(); ++j) {
-    CollectorPtr col = Collector::create(specs[j], pLocale);
+  for (auto spec : specs) {
+    CollectorPtr col(Collector::create(SEXP(spec), pLocale));
     collectors.push_back(col);
   }
 
@@ -66,11 +70,12 @@ collectorsCreate(ListOf<List> specs, LocaleInfo* pLocale) {
 void CollectorCharacter::setValue(int i, const Token& t) {
   switch (t.type()) {
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators string = t.getString(&buffer);
 
-    if (t.hasNull())
+    if (t.hasNull()) {
       warn(t.row(), t.col(), "", "embedded null");
+    }
 
     SET_STRING_ELT(
         column_,
@@ -85,7 +90,7 @@ void CollectorCharacter::setValue(int i, const Token& t) {
     SET_STRING_ELT(column_, i, Rf_mkCharCE("", CE_UTF8));
     break;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
 }
 
@@ -96,13 +101,13 @@ void CollectorCharacter::setValue(int i, const std::string& s) {
 void CollectorDate::setValue(int i, const Token& t) {
   switch (t.type()) {
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators string = t.getString(&buffer);
     std::string std_string(string.first, string.second);
 
     parser_.setDate(std_string.c_str());
     bool res =
-        (format_ == "") ? parser_.parseLocaleDate() : parser_.parse(format_);
+        (format_.empty()) ? parser_.parseLocaleDate() : parser_.parse(format_);
 
     if (!res) {
       warn(t.row(), t.col(), "date like " + format_, std_string);
@@ -124,20 +129,20 @@ void CollectorDate::setValue(int i, const Token& t) {
     REAL(column_)[i] = NA_REAL;
     return;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
 }
 
 void CollectorDateTime::setValue(int i, const Token& t) {
   switch (t.type()) {
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators string = t.getString(&buffer);
     std::string std_string(string.first, string.second);
 
     parser_.setDate(std_string.c_str());
     bool res =
-        (format_ == "") ? parser_.parseISO8601() : parser_.parse(format_);
+        (format_.empty()) ? parser_.parseISO8601() : parser_.parse(format_);
 
     if (!res) {
       warn(t.row(), t.col(), "date like " + format_, std_string);
@@ -160,29 +165,30 @@ void CollectorDateTime::setValue(int i, const Token& t) {
     REAL(column_)[i] = NA_REAL;
     return;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
-
-  return;
 }
 
 void CollectorDouble::setValue(int i, const Token& t) {
   switch (t.type()) {
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators str = t.getString(&buffer);
 
+    const char* end = str.second;
     bool ok =
         parseDouble(decimalMark_, str.first, str.second, REAL(column_)[i]);
     if (!ok) {
       REAL(column_)[i] = NA_REAL;
-      warn(t.row(), t.col(), "a double", str);
+      SourceIterators org_str = t.getString(&buffer);
+      warn(t.row(), t.col(), "a double", org_str);
       return;
     }
 
-    if (str.first != str.second) {
+    if (str.second != end) {
       REAL(column_)[i] = NA_REAL;
-      warn(t.row(), t.col(), "no trailing characters", str);
+      SourceIterators org_str = t.getString(&buffer);
+      warn(t.row(), t.col(), "no trailing characters", org_str);
       return;
     }
 
@@ -193,14 +199,15 @@ void CollectorDouble::setValue(int i, const Token& t) {
     REAL(column_)[i] = NA_REAL;
     break;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
 }
 
 void CollectorDouble::setValue(int i, size_t st) { REAL(column_)[i] = st; }
 
-void CollectorFactor::insert(int i, Rcpp::String str, const Token& t) {
-  std::map<Rcpp::String, int>::iterator it = levelset_.find(str);
+void CollectorFactor::insert(
+    int i, const cpp11::r_string& str, const Token& t) {
+  auto it = levelset_.find(str);
   if (it == levelset_.end()) {
     if (implicitLevels_ || (includeNa_ && str == NA_STRING)) {
       int n = levelset_.size();
@@ -221,11 +228,11 @@ void CollectorFactor::setValue(int i, const Token& t) {
   switch (t.type()) {
   case TOKEN_EMPTY:
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators string = t.getString(&buffer);
 
-    Rcpp::String std_string =
-        pEncoder_->makeSEXP(string.first, string.second, t.hasNull());
+    cpp11::r_string std_string(
+        pEncoder_->makeSEXP(string.first, string.second, t.hasNull()));
     insert(i, std_string, t);
     return;
   };
@@ -237,7 +244,7 @@ void CollectorFactor::setValue(int i, const Token& t) {
     }
     return;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
 }
 
@@ -245,18 +252,20 @@ void CollectorInteger::setValue(int i, const Token& t) {
 
   switch (t.type()) {
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators str = t.getString(&buffer);
 
     bool ok = parseInt(str.first, str.second, INTEGER(column_)[i]);
     if (!ok) {
       INTEGER(column_)[i] = NA_INTEGER;
-      warn(t.row(), t.col(), "an integer", str);
+      SourceIterators org_str = t.getString(&buffer);
+      warn(t.row(), t.col(), "an integer", org_str);
       return;
     }
 
     if (str.first != str.second) {
-      warn(t.row(), t.col(), "no trailing characters", str);
+      SourceIterators org_str = t.getString(&buffer);
+      warn(t.row(), t.col(), "no trailing characters", org_str);
       INTEGER(column_)[i] = NA_INTEGER;
       return;
     }
@@ -268,7 +277,7 @@ void CollectorInteger::setValue(int i, const Token& t) {
     INTEGER(column_)[i] = NA_INTEGER;
     break;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
 }
 
@@ -276,7 +285,7 @@ void CollectorLogical::setValue(int i, const Token& t) {
 
   switch (t.type()) {
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators string = t.getString(&buffer);
     std::string str(string.first, string.second);
     size_t len = string.second - string.first;
@@ -302,22 +311,23 @@ void CollectorLogical::setValue(int i, const Token& t) {
     return;
     break;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
 }
 
 void CollectorNumeric::setValue(int i, const Token& t) {
   switch (t.type()) {
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators str = t.getString(&buffer);
 
     bool ok = parseNumber(
         decimalMark_, groupingMark_, str.first, str.second, REAL(column_)[i]);
 
     if (!ok) {
+      SourceIterators org_str = t.getString(&buffer);
       REAL(column_)[i] = NA_REAL;
-      warn(t.row(), t.col(), "a number", str);
+      warn(t.row(), t.col(), "a number", org_str);
       return;
     }
 
@@ -328,20 +338,20 @@ void CollectorNumeric::setValue(int i, const Token& t) {
     REAL(column_)[i] = NA_REAL;
     break;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
 }
 
 void CollectorTime::setValue(int i, const Token& t) {
   switch (t.type()) {
   case TOKEN_STRING: {
-    boost::container::string buffer;
+    std::string buffer;
     SourceIterators string = t.getString(&buffer);
     std::string std_string(string.first, string.second);
 
     parser_.setDate(std_string.c_str());
     bool res =
-        (format_ == "") ? parser_.parseLocaleTime() : parser_.parse(format_);
+        (format_.empty()) ? parser_.parseLocaleTime() : parser_.parse(format_);
 
     if (!res) {
       warn(t.row(), t.col(), "time like " + format_, std_string);
@@ -350,8 +360,8 @@ void CollectorTime::setValue(int i, const Token& t) {
     }
 
     DateTime dt = parser_.makeTime();
-    if (!dt.validTime()) {
-      warn(t.row(), t.col(), "valid date", std_string);
+    if (!dt.validDuration()) {
+      warn(t.row(), t.col(), "valid duration", std_string);
       REAL(column_)[i] = NA_REAL;
       return;
     }
@@ -363,14 +373,13 @@ void CollectorTime::setValue(int i, const Token& t) {
     REAL(column_)[i] = NA_REAL;
     return;
   case TOKEN_EOF:
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
 }
 
 void CollectorRaw::setValue(int i, const Token& t) {
   if (t.type() == TOKEN_EOF) {
-    Rcpp::stop("Invalid token");
+    cpp11::stop("Invalid token");
   }
   SET_VECTOR_ELT(column_, i, t.asRaw());
-  return;
 }
