@@ -2,19 +2,20 @@
 #define FASTREAD_SOURCERAW_H_
 
 #include "Source.h"
-#include <Rcpp.h>
+#include "cpp11/raws.hpp"
 
 class SourceRaw : public Source {
-  Rcpp::RawVector x_; // Make sure it doesn't get GC'd
+  cpp11::raws x_;
   const char* begin_;
   const char* end_;
 
 public:
   SourceRaw(
-      Rcpp::RawVector x,
+      cpp11::raws x,
       int skip = 0,
       bool skipEmptyRows = true,
-      const std::string& comment = "")
+      const std::string& comment = "",
+      bool skipQuotes = true)
       : x_(x) {
     begin_ = (const char*)RAW(x);
     end_ = (const char*)RAW(x) + Rf_xlength(x);
@@ -23,7 +24,7 @@ public:
     begin_ = skipBom(begin_, end_);
 
     // Skip lines, if needed
-    begin_ = skipLines(begin_, end_, skip, skipEmptyRows, comment);
+    begin_ = skipLines(begin_, end_, skip, skipEmptyRows, comment, skipQuotes);
   }
 
   const char* begin() { return begin_; }
