@@ -6,7 +6,8 @@
 #include "utils.h"
 
 class TokenizerFwf : public Tokenizer {
-  std::vector<int> beginOffset_, endOffset_;
+  std::vector<int> beginOffset_;
+  std::vector<int> endOffset_;
   std::vector<std::string> NA_;
 
   SourceIterator begin_, cur_, curLine_, end_;
@@ -20,7 +21,7 @@ public:
       const std::vector<int>& beginOffset,
       const std::vector<int>& endOffset,
       std::vector<std::string> NA = std::vector<std::string>(1, "NA"),
-      std::string comment = "",
+      const std::string& comment = "",
       bool trimWS = true,
       bool skipEmptyRows = true);
 
