@@ -1,3 +1,5 @@
+#include <utility>
+
 #include "cpp11/environment.hpp"
 #include "cpp11/function.hpp"
 #include "cpp11/list.hpp"
@@ -13,7 +15,7 @@
 #include "Warnings.h"
 
 [[cpp11::register]] cpp11::strings
-read_file_(cpp11::list sourceSpec, cpp11::list locale_) {
+read_file_(const cpp11::list& sourceSpec, const cpp11::list& locale_) {
   SourcePtr source = Source::create(sourceSpec);
   LocaleInfo locale(locale_);
 
@@ -21,7 +23,7 @@ read_file_(cpp11::list sourceSpec, cpp11::list locale_) {
       locale.encoder_.makeSEXP(source->begin(), source->end()));
 }
 
-[[cpp11::register]] cpp11::raws read_file_raw_(cpp11::list sourceSpec) {
+[[cpp11::register]] cpp11::raws read_file_raw_(const cpp11::list& sourceSpec) {
   SourcePtr source = Source::create(sourceSpec);
 
   cpp11::writable::raws res(
@@ -31,8 +33,8 @@ read_file_(cpp11::list sourceSpec, cpp11::list locale_) {
 }
 
 [[cpp11::register]] cpp11::writable::strings read_lines_(
-    cpp11::list sourceSpec,
-    cpp11::list locale_,
+    const cpp11::list& sourceSpec,
+    const cpp11::list& locale_,
     std::vector<std::string> na,
     int n_max,
     bool skip_empty_rows,
@@ -41,7 +43,7 @@ read_file_(cpp11::list sourceSpec, cpp11::list locale_) {
   LocaleInfo locale(locale_);
   Reader r(
       Source::create(sourceSpec),
-      TokenizerPtr(new TokenizerLine(na, skip_empty_rows)),
+      TokenizerPtr(new TokenizerLine(std::move(na), skip_empty_rows)),
       CollectorPtr(new CollectorCharacter(&locale.encoder_)),
       progress);
 
@@ -60,18 +62,18 @@ bool isTrue(SEXP x) {
 }
 
 [[cpp11::register]] void read_lines_chunked_(
-    cpp11::list sourceSpec,
-    cpp11::list locale_,
+    const cpp11::list& sourceSpec,
+    const cpp11::list& locale_,
     std::vector<std::string> na,
     int chunkSize,
-    cpp11::environment callback,
+    const cpp11::environment& callback,
     bool skip_empty_rows,
     bool progress) {
 
   LocaleInfo locale(locale_);
   Reader r(
       Source::create(sourceSpec),
-      TokenizerPtr(new TokenizerLine(na, skip_empty_rows)),
+      TokenizerPtr(new TokenizerLine(std::move(na), skip_empty_rows)),
       CollectorPtr(new CollectorCharacter(&locale.encoder_)),
       progress);
 
@@ -86,12 +88,10 @@ bool isTrue(SEXP x) {
     R6method(callback, "receive")(out, pos);
     pos += out.size();
   }
-
-  return;
 }
 
-[[cpp11::register]] cpp11::list
-read_lines_raw_(cpp11::list sourceSpec, int n_max = -1, bool progress = false) {
+[[cpp11::register]] cpp11::list read_lines_raw_(
+    const cpp11::list& sourceSpec, int n_max = -1, bool progress = false) {
 
   Reader r(
       Source::create(sourceSpec),
@@ -103,9 +103,9 @@ read_lines_raw_(cpp11::list sourceSpec, int n_max = -1, bool progress = false) {
 }
 
 [[cpp11::register]] void read_lines_raw_chunked_(
-    cpp11::list sourceSpec,
+    const cpp11::list& sourceSpec,
     int chunkSize,
-    cpp11::environment callback,
+    const cpp11::environment& callback,
     bool progress) {
 
   Reader r(
@@ -125,18 +125,16 @@ read_lines_raw_(cpp11::list sourceSpec, int n_max = -1, bool progress = false) {
     R6method(callback, "receive")(out, pos);
     pos += out.size();
   }
-
-  return;
 }
 
 typedef std::vector<CollectorPtr>::iterator CollectorItr;
 
 [[cpp11::register]] cpp11::sexp read_tokens_(
-    cpp11::list sourceSpec,
-    cpp11::list tokenizerSpec,
-    cpp11::list colSpecs,
-    cpp11::strings colNames,
-    cpp11::list locale_,
+    const cpp11::list& sourceSpec,
+    const cpp11::list& tokenizerSpec,
+    const cpp11::list& colSpecs,
+    const cpp11::strings& colNames,
+    const cpp11::list& locale_,
     int n_max,
     bool progress) {
 
@@ -152,13 +150,14 @@ typedef std::vector<CollectorPtr>::iterator CollectorItr;
 }
 
 [[cpp11::register]] void read_tokens_chunked_(
-    cpp11::list sourceSpec,
-    cpp11::environment callback,
+    const cpp11::list& sourceSpec,
+    const cpp11::environment& callback,
     int chunkSize,
-    cpp11::list tokenizerSpec,
-    cpp11::list colSpecs,
-    cpp11::strings colNames,
-    cpp11::list locale_,
+    const cpp11::list& tokenizerSpec,
+    const cpp11::list& colSpecs,
+    const cpp11::strings& colNames,
+    const cpp11::list& locale_,
+    const cpp11::sexp& spec,
     bool progress) {
 
   LocaleInfo l(locale_);
@@ -175,18 +174,21 @@ typedef std::vector<CollectorPtr>::iterator CollectorItr;
     if (out.nrow() == 0) {
       return;
     }
+
+    // We use the C API directly, as we are modifying the read-only data_frame
+    // here.
+    Rf_setAttrib(out, Rf_install("spec"), spec);
+
     R6method(callback, "receive")(out, pos);
     pos += out.nrow();
   }
-
-  return;
 }
 
 [[cpp11::register]] cpp11::sexp melt_tokens_(
-    cpp11::list sourceSpec,
-    cpp11::list tokenizerSpec,
-    cpp11::list colSpecs,
-    cpp11::list locale_,
+    const cpp11::list& sourceSpec,
+    const cpp11::list& tokenizerSpec,
+    const cpp11::list& colSpecs,
+    const cpp11::list& locale_,
     int n_max,
     bool progress) {
 
@@ -201,12 +203,12 @@ typedef std::vector<CollectorPtr>::iterator CollectorItr;
 }
 
 [[cpp11::register]] void melt_tokens_chunked_(
-    cpp11::list sourceSpec,
-    cpp11::environment callback,
+    const cpp11::list& sourceSpec,
+    const cpp11::environment& callback,
     int chunkSize,
-    cpp11::list tokenizerSpec,
-    cpp11::list colSpecs,
-    cpp11::list locale_,
+    const cpp11::list& tokenizerSpec,
+    const cpp11::list& colSpecs,
+    const cpp11::list& locale_,
     bool progress) {
 
   LocaleInfo l(locale_);
@@ -226,14 +228,12 @@ typedef std::vector<CollectorPtr>::iterator CollectorItr;
     R6method(callback, "receive")(out, pos);
     pos += out.nrow();
   }
-
-  return;
 }
 
 [[cpp11::register]] std::vector<std::string> guess_types_(
-    cpp11::list sourceSpec,
-    cpp11::list tokenizerSpec,
-    cpp11::list locale_,
+    const cpp11::list& sourceSpec,
+    const cpp11::list& tokenizerSpec,
+    const cpp11::list& locale_,
     int n) {
   Warnings warnings;
   SourcePtr source = Source::create(sourceSpec);
@@ -246,8 +246,9 @@ typedef std::vector<CollectorPtr>::iterator CollectorItr;
   std::vector<CollectorPtr> collectors;
   for (Token t = tokenizer->nextToken(); t.type() != TOKEN_EOF;
        t = tokenizer->nextToken()) {
-    if (t.row() >= (size_t)n)
+    if (t.row() >= (size_t)n) {
       break;
+    }
 
     // Add new collectors, if needed
     if (t.col() >= collectors.size()) {
@@ -265,8 +266,8 @@ typedef std::vector<CollectorPtr>::iterator CollectorItr;
   }
 
   std::vector<std::string> out;
-  for (size_t j = 0; j < collectors.size(); ++j) {
-    cpp11::strings col(collectors[j]->vector());
+  for (auto& collector : collectors) {
+    cpp11::strings col(collector->vector());
     out.push_back(collectorGuess(SEXP(col), cpp11::list(locale_)));
   }
 
