@@ -24,14 +24,18 @@ skip_if_no_clipboard <- function() {
   return(invisible(TRUE))
 }
 
-with_crayon <- function(expr) {
+skip_if_edition_second <- function() {
+  skip_if_not(edition_first())
+}
 
-  old <- options(crayon.enabled = TRUE, crayon.colors = 16)
-  crayon::num_colors(forget = TRUE)
-  on.exit({
-    options(old)
-    crayon::num_colors(forget = TRUE)
-  })
+skip_if_edition_first <- function() {
+  skip_if(edition_first())
+}
 
-  force(expr)
+edition_variant <- function() {
+  paste0("edition-", edition_get())
+}
+
+skip_if_edition_first_windows <- function() {
+  if (edition_first()) skip_on_os("windows")
 }
