@@ -193,8 +193,9 @@ test_that("AccumulateCallback works as intended", {
 
 test_that("Chunks include their spec (#1143)", {
   res <- read_csv_chunked(readr_example("mtcars.csv"),
-      callback = ListCallback$new(function(x, pos) spec(x)),
-      chunk_size = 20)
+    callback = ListCallback$new(function(x, pos) spec(x)),
+    chunk_size = 20
+  )
 
   expect_equal(res[[1]]$cols, spec_csv(readr_example("mtcars.csv"))$cols)
 })
